Coverage for /Users/marco/Code/django-rosetta/rosetta/urls: 100.00%

# Coverage for /Users/marco/Code/django-rosetta/rosetta/urls : 100.00%

## 5 statements 5 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 | try: from django.conf.urls import patterns, url except ImportError: from django.conf.urls.defaults import patterns, url urlpatterns = patterns('rosetta.views', url(r'^$', 'home', name='rosetta-home'), url(r'^pick/$', 'list_languages', name='rosetta-pick-file'), url(r'^download/$', 'download_file', name='rosetta-download-file'), url(r'^select/(?P<langid>[\w\-]+)/(?P<idx>\d+)/$', 'lang_sel', name='rosetta-language-selection'), )